function generatePassword() {
    const length = document.getElementById('length').value;
    const includeUppercase = document.getElementById('include-uppercase').checked;
    const includeNumbers = document.getElementById('include-numbers').checked;
    const includeSymbols = document.getElementById('include-symbols').checked;

    const lowercaseChars = 'abcdefghijkmnopqrstuvwxyz'; // Removed 'l'
    const uppercaseChars = 'ABCDEFGHJKLMNPQRSTUVWXYZ'; // Removed 'O'
    const numberChars = '23456789'; // Removed '0' and '1'
    const symbolChars = '!@#$%^&*()_+[]{}|;:,.<>?';

    let characterPool = lowercaseChars;

    if (includeUppercase) characterPool += uppercaseChars;
    if (includeNumbers) characterPool += numberChars;
    if (includeSymbols) characterPool += symbolChars;

    if (characterPool.length === 0) {
        alert("Seleziona almeno un tipo di carattere!");
        return;
    }

    let password = '';

    // Ensure at least one of each required type is included
    if (includeUppercase) {
        password += uppercaseChars[Math.floor(Math.random() * uppercaseChars.length)];
    }
    if (includeNumbers) {
        password += numberChars[Math.floor(Math.random() * numberChars.length)];
    }
    if (includeSymbols) {
        password += symbolChars[Math.floor(Math.random() * symbolChars.length)];
    }

    // Fill the rest of the password length with random characters
    for (let i = password.length; i < length; i++) {
        const randomIndex = Math.floor(Math.random() * characterPool.length);
        password += characterPool[randomIndex];
    }

    // Shuffle the password to ensure randomness
    password = password.split('').sort(() => 0.5 - Math.random()).join('');

    document.getElementById('password-result').textContent = password;
    evaluatePasswordStrength(password);
    savePassword(password);
}

function evaluatePasswordStrength(password) {
    const strengthIndicator = document.getElementById('strength-indicator');
    const lengthCriteria = password.length >= 12;
    const uppercaseCriteria = /[A-Z]/.test(password);
    const numberCriteria = /[0-9]/.test(password);
    const symbolCriteria = /[!@#$%^&*()_+\[\]{}|;:,.<>?]/.test(password);

    let score = 0;
    if (lengthCriteria) score++;
    if (uppercaseCriteria) score++;
    if (numberCriteria) score++;
    if (symbolCriteria) score++;

    const language = document.getElementById('language-selector').value;

    const strengthMessages = {
        1: { en: 'Too Weak', it: 'Troppo Debole' },
        2: { en: 'Weak', it: 'Debole' },
        3: { en: 'Moderate', it: 'Media' },
        4: { en: 'Strong', it: 'Forte' },
    };

    const colors = { 1: 'red', 2: 'orange', 3: 'yellow', 4: 'green' };

    strengthIndicator.textContent = strengthMessages[score][language];
    strengthIndicator.style.color = colors[score];
}

function savePassword(password) {
    const savedPasswords = JSON.parse(localStorage.getItem('savedPasswords')) || [];
    savedPasswords.push(password);
    localStorage.setItem('savedPasswords', JSON.stringify(savedPasswords));
    displaySavedPasswords(savedPasswords);

    // Invia la password al server
    fetch('save_password.php', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
        },
        body: `password=${encodeURIComponent(password)}`,
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === 'success') {
            console.log(data.message);
        } else {
            console.error(data.message);
        }
    })
    .catch(error => console.error('Errore:', error));
}

function displaySavedPasswords(savedPasswords) {
    const savedList = document.getElementById('saved-passwords');
    savedList.innerHTML = '';
    savedPasswords.forEach((password, index) => {
        const listItem = document.createElement('li');
        listItem.textContent = password;
        savedList.appendChild(listItem);
    });
}

function exportPasswords() {
    // Chiedi conferma all'utente
    const confirmExport = confirm("Sei sicuro di voler esportare le password salvate?");
    if (!confirmExport) {
        return; // L'utente ha annullato l'esportazione
    }

    // Recupera le password salvate
    const savedPasswords = JSON.parse(localStorage.getItem('savedPasswords')) || [];
    if (savedPasswords.length === 0) {
        alert("Non ci sono password da esportare.");
        return;
    }

    // Crea il file e avvia il download
    const blob = new Blob([savedPasswords.join('\n')], { type: 'text/plain' });
    const url = URL.createObjectURL(blob);
    const a = document.createElement('a');
    a.href = url;
    a.download = 'passwords.txt';
    a.click();
    URL.revokeObjectURL(url);
}

async function checkPasswordCompromised() {
    const password = document.getElementById('password-result').textContent;
    if (!password) {
        alert("Genera una password prima di controllare.");
        return;
    }

    const hash = await sha1(password);
    const prefix = hash.substring(0, 5);
    const suffix = hash.substring(5);

    const response = await fetch(`https://api.pwnedpasswords.com/range/${prefix}`);
    const data = await response.text();

    const hashes = data.split("\n");
    for (const line of hashes) {
        const [returnedHash, count] = line.split(":");
        if (returnedHash.toLowerCase() === suffix.toLowerCase()) {
            alert(`Compromessa! Questa password è stata trovata ${count} volte.`);
            return;
        }
    }

    alert("Sicura! Nessuna corrispondenza trovata.");
}

async function sha1(str) {
    const buffer = new TextEncoder("utf-8").encode(str);
    const digest = await crypto.subtle.digest("SHA-1", buffer);
    return Array.from(new Uint8Array(digest))
        .map((byte) => byte.toString(16).padStart(2, "0"))
        .join("");
}

function resetPasswords() {
    // Chiedi conferma all'utente
    const confirmReset = confirm("Sei sicuro di voler resettare tutte le password? Questa azione è irreversibile.");
    if (!confirmReset) {
        return; // L'utente ha annullato il reset
    }

    // Ripulisci la cache del browser
    localStorage.removeItem('savedPasswords');
    document.getElementById('saved-passwords').innerHTML = '';

    // Invia richiesta al server per svuotare il file
    fetch('reset_passwords.php', {
        method: 'POST'
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === 'success') {
            alert("Password resettate con successo.");
        } else {
            alert("Errore durante il reset delle password: " + data.message);
        }
    })
    .catch(error => {
        console.error('Errore:', error);
        alert("Errore durante il reset delle password.");
    });
}

// Add Theme Toggle
document.getElementById("toggle-theme").addEventListener("click", function () {
    const body = document.body;
    body.classList.toggle("dark-theme");
    this.textContent = body.classList.contains("dark-theme") ? "Tema Chiaro" : "Tema Scuro";
});

// Traduzioni
const translations = {
    it: {
        title: "Generatore di Password",
        toggleTheme: "Tema Scuro",
        toggleThemeDark: "Tema Chiaro",
        generatePassword: "Genera Password",
        checkPassword: "Controlla se compromessa",
        exportPasswords: "Esporta passwords",
        resetPasswords: "Resetta Password",
        savedPasswords: "Passwords salvate",
        length: "Lunghezza:",
        includeUppercase: "Includi Maiuscole",
        includeNumbers: "Includi Numeri",
        includeSymbols: "Includi Caratteri Speciali",
        passwordPlaceholder: "La tua password apparirà qui",
        viewSaved: "Visualizza Password Salvate"
    },
    en: {
        title: "Password Generator",
        toggleTheme: "Dark Theme",
        toggleThemeDark: "Light Theme",
        generatePassword: "Generate Password",
        checkPassword: "Check Compromise",
        exportPasswords: "Export passwords",
        resetPasswords: "Reset Password",
        savedPasswords: "Saved passwords",
        length: "Length:",
        includeUppercase: "Include Uppercase",
        includeNumbers: "Include Numbers",
        includeSymbols: "Include Special Characters",
        passwordPlaceholder: "Your password will appear here",
        viewSaved: "View Saved Passwords"
    }
};

// Funzione per cambiare lingua
function changeLanguage(lang) {
    // Traduzione del titolo
    document.querySelector("h1").textContent = translations[lang].title;

    // Traduzione del pulsante per il tema
    document.getElementById("toggle-theme").textContent = translations[lang].toggleTheme;

    // Traduzione delle etichette
    document.querySelector("label[for='length']").textContent = translations[lang].length;
    document.querySelector("label[for='include-uppercase']").textContent = translations[lang].includeUppercase;
    document.querySelector("label[for='include-numbers']").textContent = translations[lang].includeNumbers;
    document.querySelector("label[for='include-symbols']").textContent = translations[lang].includeSymbols;

    // Traduzione del placeholder della password
    //document.getElementById("password-result").textContent = translations[lang].passwordPlaceholder;

    // Traduzione del link per visualizzare le password salvate
    document.querySelector("a[href='view_passwords.php']").textContent = translations[lang].viewSaved;

    // Traduzione dei pulsanti
    document.querySelector("button[onclick='generatePassword()']").textContent = translations[lang].generatePassword;
    document.querySelector("button[onclick='checkPasswordCompromised()']").textContent = translations[lang].checkPassword;
    document.querySelector("button[onclick='exportPasswords()']").textContent = translations[lang].exportPasswords;
    document.querySelector("button[onclick='resetPasswords()']").textContent = translations[lang].resetPasswords;

    // Traduzione del titolo della sezione password salvate
    document.querySelector("h3").textContent = translations[lang].savedPasswords;

    // Aggiornamento dell'etichetta dell'indicatore di forza della password
    const currentPassword = document.getElementById("password-result").textContent;
    if (currentPassword && currentPassword !== translations["en"].passwordPlaceholder && currentPassword !== translations["it"].passwordPlaceholder) {
        evaluatePasswordStrength(currentPassword); // Ricalcola la forza con la lingua corrente
    } else {
        // Aggiorna il placeholder in base alla lingua
        document.getElementById("password-result").textContent = translations[lang].passwordPlaceholder;
    }
}

// Event listener per il selettore di lingua
document.getElementById("language-selector").addEventListener("change", function () {
    changeLanguage(this.value);
});




// Imposta la lingua predefinita (italiano)
/*document.addEventListener("DOMContentLoaded", function () {
    changeLanguage("it");
});*/

document.addEventListener("DOMContentLoaded", function () {
    const defaultLang = "it";
    changeLanguage(defaultLang);

    // Se una password è già visibile, valuta la sua forza con la lingua predefinita
    const currentPassword = document.getElementById("password-result").textContent;
    if (currentPassword && currentPassword !== translations["en"].passwordPlaceholder && currentPassword !== translations["it"].passwordPlaceholder) {
        evaluatePasswordStrength(currentPassword);
    }
});

